#
# spec file for package protontricks
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019 Matthias Fehring <buschmann23@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
Name:           protontricks
Version:        1.11.0
Release:        1.2
Summary:        Winetricks for Proton-enabled Games
License:        GPL-3.0-only
Group:          System/Emulators/PC
URL:            https://github.com/Matoking/protontricks
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  python-rpm-macros
# START TESTING SECTION
BuildRequires:  python3-Pillow
BuildRequires:  python3-pytest >= 3.6
BuildRequires:  python3-setuptools_scm
BuildRequires:  python3-vdf >= 2.4
BuildRequires:  update-desktop-files
# needed for the desktop file icon
BuildRequires:  wine
# END TESTING SECTION
Requires:       python3-Pillow
Requires:       python3-setuptools
Requires:       python3-vdf
Requires:       winetricks
Requires:       zenity
BuildArch:      noarch

%description
A simple wrapper that does winetricks things for Proton enabled games.

%prep
%setup -q
chmod -x src/protontricks/cli/main.py

# Fix non-executable-script check
chmod +x src/protontricks/data/scripts/*.sh

%build
%python3_build

%install
%python3_install
%suse_update_desktop_file -r protontricks Game Amusement
%fdupes -s %{buildroot}

%check
export LC_ALL='en_US.utf8'
PYTHONPATH=$PYTHONPATH:%{buildroot}%{python3_sitelib} py.test-%{python3_version}

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/%{name}
%{_bindir}/%{name}-desktop-install
%{_bindir}/%{name}-launch
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-launch.desktop
%{python3_sitelib}/*

%changelog
* Fri Jan  5 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 1.11.0:
  * Show app icons for custom shortcuts in the app selector
  * Verbose flag can be enabled with -vv for additional debug logging
  * Fix Protontricks not recognizing supported Steam Runtime
    installation due to changed name
  * Fix Protontricks not recognizing default Proton installation for
    games with different Proton preselected by Valve testing
  * Fix Protontricks crash when app has an unidentifiable app icon
* Mon Oct 23 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Fix incorrect use of mode parameter in _service file mentioned at
  https://build.opensuse.org/request/show/1119325?notification_id=43740251
* Sat Oct 21 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Use python3-setuptools to fix runtime dependency
* Wed Sep 20 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 1.10.5:
  * Convert icon to RGB mode before conversion
- Changes from 1.10.4:
  * Document protontricks-launch
  * Ensure all app icons have 32x32 size
  * Add utils.get_cache_dir
  * Ignore possible extra data in binary VDF
  * Do not use loop to check for launcher
  * Fix outdated protontricks-launch help text
- Add required packages python3-Pillow and setuptools
- Add fdupes as build requirement and use it
* Fri Jul 14 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 1.10.3:
  * Replace deprecated setuptools parameter
  * Disable background-wineserver by default
  * Always look for Flatpak Steam installation
  * Add Sniper as supported runtime
  * Check for 'steamapps' in case-insensitive manner
- Changes from 1.10.2:
  * Update section on community packages
  * Remove unused imports
  * Update section on community package
  * Fix locale settings on Steam Deck
  * Find Windows shortcut prefix properly
  * Check and log more permission errors gracefully
* Sat Dec 31 2022 Jan-Luca Kiok <me@jlk.one>
- Change service url protocol from git to https
* Sat Dec 31 2022 Jan-Luca Kiok <me@jlk.one>
- Update to version 1.10.1:
  + Fixed
  * Fix crash when parsing appinfo.vdf V28 version introduced in
    Steam beta
- Changes from 1.10.0:
  + Added
  * Prompt the user for a Steam installation if multiple
    installations are found
- Changes from 1.9.2:
  + Fixed
  * Fix random crashes when running Wine commands due to race
    condition in Wine launcher script
- Changes from 1.9.1:
  + Added
  * Print a warning when multiple Steam directories are detected
    and "STEAM_DIR" is not used to specify the directory
  + Changed
  * Launch Steam Runtime sandbox with "--bus-name" parameter
    instead of the now deprecated "--socket"
  + Fixed
  * Fix various crashes due to Wine processes under Steam Runtime
    sandbox using the incorrect working directory
- Changes from 1.9.0:
  + Added
  * Add "-l/--list" command to list all games
  + Fixed
  * Fix "wineserver -w" calls hanging when legacy Steam Runtime
    and background wineserver are enabled
  * Do not attempt to launch bwrap-launcher if bwrap is not
    available
- Changes from 1.8.2:
  + Fixed
  * Fix Wine crash on newer Steam Runtime installations due to
    renamed runtime executable
  * Fix graphical Wine applications crashing on Wayland
  * Fix Protontricks crash caused by Steam shortcuts created by
    3rd party applications such as Lutris
- Changes from 1.8.1:
  + Added
  * Prompt the user to update Flatpak permissions if inaccessible
    paths are detected
  + Fixed
  * Fix Proton discovery on Steam Deck
  + Removed
  * Drop Python 3.5 support
* Fri Mar 11 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.8.0:
  + Added
  * fsync/esync is enabled by default
  * PROTON_NO_FSYNC and PROTON_NO_ESYNC environment variables
    are supported
  * Improve Wine command startup time by launching a background
    wineserver for the duration of the Protontricks session.
    This is enabled by default for bwrap, and can also be toggled
    manually with --background-wineserver/--no-background-wineserver.
  * Improve Wine command startup time with bwrap by creating a
    single container and launching all Wine processes inside it.
  + Fixed
  * Fix Wine crash when the Steam application and Protontricks
    are running at the same time
  * Fix Steam installation detection when both non-Flatpak and
    Flatpak versions of Steam are installed for the same user
  * Fix Protontricks crash when Proton installation is incomplete
  * Fix Protontricks crash when both Flatpak and non-Flatpak
    versions of Steam are installed
  * Fix duplicate log messages when using protontricks-launch
  * Fix error dialog not being displayed when using
    protontricks-launch
- Changes from 1.7.0:
  + Changed
  * Enable usage of Flatpak Protontricks with non-Flatpak Steam.
    Flatpak Steam is prioritized if both are found.
  + Fixed
  * bwrap is only disabled when the Flatpak installation is
    too old. Flatpak 1.12.1 and newer support sub-sandboxes.
  * Remove Proton installations from app listings
- Changes from 1.6.2:
  + Changed
  * Return code is now returned from the executed user commands
  * Return code 1 is returned for most Protontricks errors
    instead of -1
- Changes from 1.6.1:
  + Fixed
  * Fix duplicate Steam application entries
  * Fix crash on Python 3.5
- Run spec-cleaner
* Tue Aug 24 2021 Matthias Fehring <buschmann23@opensuse.org>
- Update to version 1.6.0
  + Added
  * Add protontricks-launch script to launch Windows executables
    using Proton app specific Wine prefixes
  * Add desktop integration for Windows executables, which can
    now be launched using Protontricks
  * Add protontricks-desktop-install to install desktop integration
    for the local user. This is only necessary if the installation
    method doesn't do this automatically.
  * Add error dialog for displaying error information when Protontricks
    has been launched from desktop and no user-visible terminal
    is available.
  * Add YAD as GUI provider. YAD is automatically used instead of
    Zenity when available as it supports additional features.
  + Changed
  * Improved GUI dialog. The prompt to select the Steam app now
    uses a list dialog with support for scrolling, search and app
    icons. App icons are only supported on YAD.
  + Fixed
  * Display proper error messages in certain cases when corrupted
    VDF files are found
  * Fix crash caused by appmanifest files that can't be read due
    to insufficient permissions
  * Fix crash caused by non-Proton compatibility tool being enabled
    for the selected app
  * Fix erroneous warning when Steam library is inside a
    case-insensitive file system
- Changes from 1.5.2
  + Fixed
  * Custom Proton installations now use Steam Runtime installations
    when applicable
  * Fix crash caused by older Steam app installations using a
    different app manifest structure
  * Fix crash caused by change to lowercase field names in multiple
    VDF files
  * Fix crash caused by change in the Steam library folder
    configuration file
- Changes from 1.5.1
  + Fixed
  * bwrap containerization now tries to mount more root directories
    except those that have been blacklisted due to potential issues
- Changes from 1.5.0
  + Added
  * Use bwrap containerization with newer Steam Runtime installations.
    The old behavior can be enabled with --no-bwrap in case of problems.
  + Fixed
  * User-provided WINE and WINESERVER environment variables are
    used when Steam Runtime is enabled
  * Fixed crash caused by changed directory name in Proton
    Experimental update
* Sat Feb  6 2021 Matthias Fehring <buschmann23@opensuse.org>
- Update to version 1.4.4
  + Fixed
  * Display a proper error message when Proton installation is
    incomplete due to missing Steam Runtime
  * Display a proper warning when a tool manifest is empty
  * Fix crash caused by changed directory structure in Steam
    Runtime update
* Sun Jan 10 2021 Matthias Fehring <buschmann23@opensuse.org>
- Updated to version 1.4.3
  + Fixed
  * Add support for newer Steam Runtime versions
- Updated to version 1.4.2
  + Fixed
  * Fix crash with newer Steam client beta caused by differently
    cased keys in loginusers.vdf
  + Added
  * Print a warning if both steamapps and SteamApps directories
    are found inside the same library directory
  + Changed
  * Print full help message when incorrect parameters are provided
* Wed May  6 2020 Matthias Fehring <buschmann23@opensuse.org>
- Updated to version 1.4.1
  + Fixed
  * Fixed crash caused by Steam library paths containing special
    characters
  * Fixed crash with Proton 5.0 caused by Steam Runtime being used
    unnecessarily with all binaries
- Updated to version 1.4
  + Added
  * System-wide compatibility tool directories are now searched
    for Proton installations
  + Changed
  * Drop Python 3.4 compatibility. Python 3.4 compatibility has
    been broken since 1.2.2.
  + Fixed
  * Zenity no longer crashes the script if locale is incapable of
    processing the arguments.
  * Selecting "Cancel" in the GUI window now prints a proper message
    instead of an error.
  * Add workaround for Zenity crashes not handled by the previous fix
- Updated to version 1.3.1
  + Fixed
  * Fix Proton prefix detection when the prefix directory is located
    inside a SteamApps directory instead of steamapps
  * Use the most recently used Proton prefix when multiple prefix
    directories are found for a single game
  * Fix Python 3.5 compatibility
* Thu Nov  7 2019 Matthias Fehring <buschmann23@opensuse.org>
- Added new Requires zenity: new dependency
* Thu Nov  7 2019 Matthias Fehring <buschmann23@opensuse.org>
- Initial package version 1.3
